==> extension_kde_plasma-6.3.4.tar.xz: extension_kde_plasma-6.3.4/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[ ! -f /lib/libboost_atomic.so ] && echo "Installing boost" && extension --install boost && echo "Finished boost"
[[ $(command -v ffmpeg) == "" ]] && echo "Installing ffmpeg" && extension --install ffmpeg && echo "Finished ffmpeg"
[[ $(command -v gtk-launch) == "" ]] && echo "Installing gtk3" && extension --install gtk3 && echo "Finished gtk3"
[ ! -d /opt/kf6-6.14.0 ] && echo "Installing kde_framework:6.14.0" && extension --install kde_framework:6.14.0 && echo "Finished kde_framework:6.14.0"
[ ! -d $KF6_PREFIX/lib/cmake/KF6KirigamiAddons ] && echo "Installing kirigami_addons" && extension --install kirigami_addons && echo "Finished kirigami_addons"
[ ! -f /lib/libdisplay-info.so ] && echo "Installing libdisplay_info" && extension --install libdisplay_info && echo "Finished libdisplay_info"
[[ $(command -v pwscore) == "" ]] && echo "Installing libpwquality" && extension --install libpwquality && echo "Finished libpwquality"
[[ $(command -v qalc) == "" ]] && echo "Installing libqalculate" && extension --install libqalculate && echo "Finished libqalculate"
[[ $(command -v nl-link-list) == "" ]] && echo "Installing libnl" && extension --install libnl && echo "Finished libnl"
[[ $(command -v cvt) == "" ]] && echo "Installing libxcvt" && extension --install libxcvt && echo "Finished libxcvt"
[[ $(command -v xkbcli) == "" ]] && echo "Installing libxkbcommon" && extension --install libxkbcommon && echo "Finished libxkbcommon"
[[ $(command -v glxinfo) == "" ]] && echo "Installing mesa" && extension --install mesa && echo "Finished mesa"
[[ $(command -v wayland-scanner) == "" ]] && echo "Installing wayland" && extension --install wayland && echo "Finished wayland"
[[ $(command -v opencv_version) == "" ]] && echo "Installing opencv" && extension --install opencv && echo "Finished opencv"
[[ $(command -v phononsettings) == "" ]] && echo "Installing phonon" && extension --install phonon && echo "Finished phonon"
[[ $(command -v pipewire) == "" ]] && echo "Installing pipewire" && extension --install pipewire && echo "Finished pipewire"
[ ! -f $KF6_PREFIX/lib/libKF6PulseAudioQt.so ] && echo "Installing pulseaudio_qt" && extension --install pulseaudio_qt && echo "Finished pulseaudio_qt"
[[ $(command -v qcatool-qt6) == "" ]] && echo "Installing qca" && extension --install qca && echo "Finished qca"
[ ! -f /lib/libQCoro6Core.so ] && echo "Installing qcoro" && extension --install qcoro && echo "Finished qcoro"
[[ $(command -v sassc) == "" ]] && echo "Installing sassc" && extension --install sassc && echo "Finished sassc"
[[ $(command -v taglib-config) == "" ]] && echo "Installing taglib" && extension --install taglib && echo "Finished taglib"
[ ! -f /lib/libxdo.so ] && echo "Installing xdotool" && extension --install xdotool && echo "Finished xdotool"
[ ! -f /usr/lib/xorg/modules/input/evdev_drv.so ] && echo "Installing xorg_evdev_drv" && extension --install xorg_evdev_drv && echo "Finished xorg_evdev_drv"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[ ! -d /usr/share/GConf/gsettings ] && echo "Installing gsettings_desktop_schemas" && extension --install gsettings_desktop_schemas && echo "Finished gsettings_desktop_schemas"
	[[ $(command -v canberra-gtk-play) == "" ]] && echo "Installing libcanberra" && extension --install libcanberra && echo "Finished libcanberra"
	[[ $(command -v libinput) == "" ]] && echo "Installing libinput" && extension --install libinput && echo "Finished libinput"
	[[ $(command -v pcap-config) == "" ]] && echo "Installing libpcap" && extension --install libpcap && echo "Finished libpcap"
	[[ $(command -v libwacom-list-devices) == "" ]] && echo "Installing libwacom" && extension --install libwacom && echo "Finished libwacom"
	#[[ $(command -v xsetwacom) == "" ]] && echo "Installing xorg_wacom_driver" && extension --install xorg_wacom_driver && echo "Finished xorg_wacom_driver"
	[[ $(command -v pam_namespace_helper) == "" ]] && echo "Installing linux_pam" && extension --install linux_pam && echo "Finished linux_pam"
	[[ $(command -v fancontrol) == "" ]] && echo "Installing lm_sensors" && extension --install lm_sensors && echo "Finished lm_sensors"
	[ ! -d /usr/share/icons/oxygen ] && echo "Installing oxygen_icons" && extension --install oxygen_icons && echo "Finished oxygen_icons"
	[[ $(command -v lspci) == "" ]] && echo "Installing pciutils" && extension --install pciutils && echo "Finished pciutils"
	#[[ $(command -v powerprofilesctl) == "" ]] && echo "Installing power_profiles_daemon" && extension --install power_profiles_daemon && echo "Finished power_profiles_daemon"
	[ ! -d /usr/lib/python*/site-packages/psutil-* ] && echo "Installing py_psutil" && extension --install py_psutil && echo "Finished py_psutil"
	[ ! -d /usr/lib/python*/site-packages/pygdbmi-* ] && echo "Installing py_pygdbmi" && extension --install py_pygdbmi && echo "Finished py_pygdbmi"
	[ ! -d /usr/lib/python*/site-packages/sentry_sdk ] && echo "Installing py_sentry_sdk" && extension --install py_sentry_sdk && echo "Finished py_sentry_sdk"
	[ ! -d /usr/lib/python*/site-packages/urllib3 ] && echo "Installing py_urllib3" && extension --install py_urllib3 && echo "Finished py_urllib3"
fi
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v appstreamcli) == "" ]] && echo "Installing appstream" && extension --install appstream && echo "Finished appstream"
	[ ! -f /lib/libGLU.so ] && echo "Installing glu" && extension --install glu && echo "Finished glu"
	#[[ $(command -v ibus-daemon) == "" ]] && echo "Installing ibus" && extension --install ibus && echo "Finished ibus"
	#[[ $(command -v QtWebEngineProcess) == "" ]] && echo "Installing qtwebengine" && extension --install qtwebengine && echo "Finished qtwebengine"
fi

if [ $BUILD_ALL == "false" ]; then # && [[ $(command -v certutil) == "" ]]; then
	echo "kde_plasma _"									>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "kde_plasma _" 								>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt

==> extension_kde_plasma-6.3.5.tar.xz: extension_kde_plasma-6.3.5/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[ ! -f /lib/libboost_atomic.so ] && echo "Installing boost" && extension --install boost && echo "Finished boost"
[[ $(command -v ffmpeg) == "" ]] && echo "Installing ffmpeg" && extension --install ffmpeg && echo "Finished ffmpeg"
[[ $(command -v gtk-launch) == "" ]] && echo "Installing gtk3" && extension --install gtk3 && echo "Finished gtk3"
#[ ! -d /opt/kf6-6.14.0 ] && echo "Installing kde_framework:6.14.0" && extension --install kde_framework:6.14.0 && echo "Finished kde_framework:6.14.0"
#[ ! -d $KF6_PREFIX/lib/cmake/KF6KirigamiAddons ] && echo "Installing kirigami_addons" && extension --install kirigami_addons && echo "Finished kirigami_addons"
[ ! -f /lib/libdisplay-info.so ] && echo "Installing libdisplay_info" && extension --install libdisplay_info && echo "Finished libdisplay_info"
[[ $(command -v pwscore) == "" ]] && echo "Installing libpwquality" && extension --install libpwquality && echo "Finished libpwquality"
[[ $(command -v qalc) == "" ]] && echo "Installing libqalculate" && extension --install libqalculate && echo "Finished libqalculate"
[[ $(command -v nl-link-list) == "" ]] && echo "Installing libnl" && extension --install libnl && echo "Finished libnl"
[[ $(command -v cvt) == "" ]] && echo "Installing libxcvt" && extension --install libxcvt && echo "Finished libxcvt"
[[ $(command -v xkbcli) == "" ]] && echo "Installing libxkbcommon" && extension --install libxkbcommon && echo "Finished libxkbcommon"
[[ $(command -v glxinfo) == "" ]] && echo "Installing mesa" && extension --install mesa && echo "Finished mesa"
[[ $(command -v wayland-scanner) == "" ]] && echo "Installing wayland" && extension --install wayland && echo "Finished wayland"
[[ $(command -v opencv_version) == "" ]] && echo "Installing opencv" && extension --install opencv && echo "Finished opencv"
[[ $(command -v phononsettings) == "" ]] && echo "Installing phonon" && extension --install phonon && echo "Finished phonon"
[[ $(command -v pipewire) == "" ]] && echo "Installing pipewire" && extension --install pipewire && echo "Finished pipewire"
[ ! -f $KF6_PREFIX/lib/libKF6PulseAudioQt.so ] && echo "Installing pulseaudio_qt" && extension --install pulseaudio_qt && echo "Finished pulseaudio_qt"
[[ $(command -v qcatool-qt6) == "" ]] && echo "Installing qca" && extension --install qca && echo "Finished qca"
[ ! -f /lib/libQCoro6Core.so ] && echo "Installing qcoro" && extension --install qcoro && echo "Finished qcoro"
[[ $(command -v sassc) == "" ]] && echo "Installing sassc" && extension --install sassc && echo "Finished sassc"
[[ $(command -v taglib-config) == "" ]] && echo "Installing taglib" && extension --install taglib && echo "Finished taglib"
[ ! -f /lib/libxdo.so ] && echo "Installing xdotool" && extension --install xdotool && echo "Finished xdotool"
[ ! -f /usr/lib/xorg/modules/input/evdev_drv.so ] && echo "Installing xorg_evdev_drv" && extension --install xorg_evdev_drv && echo "Finished xorg_evdev_drv"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[ ! -d /usr/share/GConf/gsettings ] && echo "Installing gsettings_desktop_schemas" && extension --install gsettings_desktop_schemas && echo "Finished gsettings_desktop_schemas"
	[[ $(command -v canberra-gtk-play) == "" ]] && echo "Installing libcanberra" && extension --install libcanberra && echo "Finished libcanberra"
	[[ $(command -v libinput) == "" ]] && echo "Installing libinput" && extension --install libinput && echo "Finished libinput"
	[[ $(command -v pcap-config) == "" ]] && echo "Installing libpcap" && extension --install libpcap && echo "Finished libpcap"
	[[ $(command -v libwacom-list-devices) == "" ]] && echo "Installing libwacom" && extension --install libwacom && echo "Finished libwacom"
	#[[ $(command -v xsetwacom) == "" ]] && echo "Installing xorg_wacom_driver" && extension --install xorg_wacom_driver && echo "Finished xorg_wacom_driver"
	[[ $(command -v pam_namespace_helper) == "" ]] && echo "Installing linux_pam" && extension --install linux_pam && echo "Finished linux_pam"
	[[ $(command -v fancontrol) == "" ]] && echo "Installing lm_sensors" && extension --install lm_sensors && echo "Finished lm_sensors"
	[ ! -d /usr/share/icons/oxygen ] && echo "Installing oxygen_icons" && extension --install oxygen_icons && echo "Finished oxygen_icons"
	[[ $(command -v lspci) == "" ]] && echo "Installing pciutils" && extension --install pciutils && echo "Finished pciutils"
	#[[ $(command -v powerprofilesctl) == "" ]] && echo "Installing power_profiles_daemon" && extension --install power_profiles_daemon && echo "Finished power_profiles_daemon"
	[ ! -d /usr/lib/python*/site-packages/psutil-* ] && echo "Installing py_psutil" && extension --install py_psutil && echo "Finished py_psutil"
	[ ! -d /usr/lib/python*/site-packages/pygdbmi-* ] && echo "Installing py_pygdbmi" && extension --install py_pygdbmi && echo "Finished py_pygdbmi"
	[ ! -d /usr/lib/python*/site-packages/sentry_sdk ] && echo "Installing py_sentry_sdk" && extension --install py_sentry_sdk && echo "Finished py_sentry_sdk"
	[ ! -d /usr/lib/python*/site-packages/urllib3 ] && echo "Installing py_urllib3" && extension --install py_urllib3 && echo "Finished py_urllib3"
fi
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v appstreamcli) == "" ]] && echo "Installing appstream" && extension --install appstream && echo "Finished appstream"
	[ ! -f /lib/libGLU.so ] && echo "Installing glu" && extension --install glu && echo "Finished glu"
	#[[ $(command -v ibus-daemon) == "" ]] && echo "Installing ibus" && extension --install ibus && echo "Finished ibus"
	#[[ $(command -v QtWebEngineProcess) == "" ]] && echo "Installing qtwebengine" && extension --install qtwebengine && echo "Finished qtwebengine"
fi

if [ $BUILD_ALL == "false" ]; then # && [[ $(command -v certutil) == "" ]]; then
	echo "kde_plasma _"									>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "kde_plasma _" 								>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
